/***************************************************************************
 *   Copyright (C) 2010 by Martin Burgemeister, Mathis Lindemann           *
 *     																	   *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#include "LuaOutput.h"

const char LuaOutput::className[] = "LuaOutput";

const Luna<LuaOutput>::RegType
        LuaOutput::Register[] = { { "print", &LuaOutput::print }, { 0, 0 } };

/**
 * \brief Sets the LuaController reference to the object which is registered in
 *        Lua.
 *
 * \param L The lua_State to use.
 */
LuaOutput::LuaOutput ( lua_State* L ) : LuaWrapper(L,"LuaController")
{
	controller_ = (LuaController*)lua_touserdata( L, 1);
}

/**
 * \brief Emtpy destructor (for Luna).
 */
LuaOutput::~LuaOutput ()
{
}

/**
 * \brief Prints a string on the UCQConsole.
 *
 * This method takes the output from the Lua print() method and prints it
 * on the UCQConsole. The print() method of Lua accepts a variable number of
 * arguments. All arguments are used by this method and appended
 * to the output string.
 *
 * \param L The lua_State to use.
 * \return The number of results.
 * \see LuaController::print(QString)
 */
int LuaOutput::print ( lua_State* L )
{
    // get number of arguments
    int cnt = lua_gettop ( L );
    QString output;

    // build string
    for ( int i = 2; i <= cnt; i++ )
    {
        if ( i > 2 )
        {
            output.append ( "\t" );
        }
        output.append ( QString ( lua_tostring(L, i) ) );
    }

    // print string
    controller_->print ( output );
    return 0;
}


