/***************************************************************************
 *   Copyright (C) 2010 by Martin Burgemeister, Mathis Lindemann   		   *
 *     																	   *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#include "LuaSort.h"

const char LuaSort::className[] = "LuaSort";

const Luna<LuaSort>::RegType LuaSort::Register[] = {
		{ "sort", &LuaSort::sort },{ "sortOrder", &LuaSort::sortOrder }, { 0, 0 } };
/**
 * \brief Sets the SortController reference to the object which is registered
 *        in Lua.
 */
LuaSort::LuaSort(lua_State * L) :
	LuaWrapper(L, "SortController") {
	sortControl_ = (SortController*) lua_touserdata(L, 1);
}

/**
 * \brief Emtpy destructor (for Luna).
 */
LuaSort::~LuaSort() {
}

/**
 * \brief Sort function.
 *
 * Calls the sort() function from SortController.
 * \see SortController::sort()
 */
int LuaSort::sort(lua_State * L) {
	// if no flags given only code will be searched

	QString flags(lua_tostring(L, 2));

	if (!flags.isEmpty()) {
		// search codepoint
		if (flags.contains("c")) {
			sortControl_->sort(SortController::CODEPOINT_SORT);
		}

		if (flags.contains("d")) {
			sortControl_->sort(SortController::COMMENT_SORT);
		}
		if (flags.contains("w")) {
			sortControl_->sort(SortController::COLLATION_SORT);
		}
	}
//	}else{
//		sortControl_->sort(SortController::DEFAULT_ORDER);
//	}

	return 0;
}
int LuaSort::sortOrder(lua_State * L) {
	// if no flags given only code will be searched

	QString flags(lua_tostring(L, 2));


	if (!flags.isEmpty()) {
		// search codepoint
		if (flags.contains("a")) {
			sortControl_->sortOrder(SortController::ASCENDING);
		}

		if (flags.contains("d")) {
			sortControl_->sortOrder(SortController::DESCENDING);
		}


	}else{
		sortControl_->sortOrder(SortController::ASCENDING);
	}

	return 0;
}
